@@ -23,6 +23,3 @@ impl super::Trace for Trace {
         unsafe { backtrace::trace_unsynchronized(cb) }
     }
 }
-
-pub use backtrace::Frame;
-pub use backtrace::Symbol;
